package VMOMI::HostCpuPackageVendor;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
